@extends(Theme::viewName('layout'))
@section('title', $album->name)

@section('breadcrumb')
    <li class="breadcrumb-item"><a href="{{ route('home') }}"><i class="fa fa-fw fa-home"></i></a></li>
    @include(Theme::viewName('partials.album_breadcrumb'))
@endsection

@section('content')
    <div class="container album-container">
        <div class="row">
            <div class="col">
                <div class="pull-right">
                    @can('edit', $album)
                        <div class="mb-3">
                            <a class="btn btn-secondary" href="{{ route('albums.show', ['id' => $album->id]) }}"><i class="fa fa-fw fa-eye"></i> @lang('gallery.manage_album_link_2')</a>
                        </div>
                    @endcan

                    @include(\App\Facade\Theme::viewName('partials.album_view_selector'))
                </div>

                <h1 class="page-title">{{ $album->name }}</h1>
                <p>{!! nl2br(e($album->description)) !!}</p>
                <div class="clearfix"><!-- --></div>
                <hr/>
            </div>
        </div>

        <div class="row">
            @foreach ($photos as $photo)
                <div class="col-sm-6 col-md-4 photo mb-3">
                    <div class="card">
                        <a href="{{ $photo->url() }}"><img src="{{ $photo->thumbnailUrl('preview') }}" alt="" class="card-img-top"/></a>
                        <div class="card-body">
                            <h4 class="card-title"><a href="{{ $photo->url() }}">{{ $photo->name }}</a></h4>
                        </div>
                        <div class="card-footer">
                            <small class="text-muted"><i class="fa fa-fw fa-calendar"></i> {{ date(UserConfig::get('date_format'), strtotime(!is_null($photo->taken_at) ? $photo->taken_at : $photo->created_at)) }}</small>
                        </div>
                    </div>
                </div>
            @endforeach
        </div>

        <div class="row" style="margin-top: 15px;">
            <div class="col text-center">
                {{ $photos->links() }}
            </div>
        </div>

        @if (count($child_albums) > 0)
            <div class="row">
                <div class="col text-center">
                    <h2 style="margin-top: 60px;"><small class="text-muted">@lang('gallery.other_albums_heading', ['album_name' => $album->name])</small></h2>
                    <p class="mb-4">@lang('gallery.other_albums_description')</p>

                    <div class="row">
                        @foreach ($child_albums as $childAlbum)
                            <div class="col-6 col-sm-4 col-md-3 text-left" style="max-width: 250px;">
                                <div class="card mb-3">
                                    <img class="card-img-top" src="{{ $childAlbum->thumbnailUrl('preview') }}" style="max-height: 120px;"/>
                                    <div class="card-body">
                                        <h5 class="card-title"><a href="{{ $childAlbum->url() }}">{{ $childAlbum->name }}</a></h5>
                                    </div>
                                    <div class="card-footer">
                                        <small class="text-muted">
                                            <i class="fa fa-fw fa-photo"></i> {{ number_format($childAlbum->photos_count) }} {{ trans_choice('gallery.photos', $childAlbum->photos_count) }}

                                            @if ($childAlbum->children_count > 0)
                                            <i class="fa fa-fw fa-book ml-3"></i> {{ number_format($childAlbum->children_count) }} {{ trans_choice('gallery.child_albums', $childAlbum->children_count) }}
                                            @endif
                                        </small>
                                    </div>
                                </div>
                            </div>
                        @endforeach
                    </div>
                </div>
            </div>
        @endif
    </div>
@endsection